@@ -127,7 +127,7 @@ class Mysql(object):
         value_str = "(" + ", ".join(value_list) + ")"
         return field_str, value_str
 
-    def insert_order_sql(self, data_info: dict, table_name: str) -> list:
+    def insert_order_sql(self, data_info: dict, table_name: str, is_need_close: bool) -> list:
         field_str, value_str = self.convert_key_value_str(**data_info)
         sql = "insert into " + "`{}` {} values {};".format(table_name, field_str, value_str)
-        return self.execute_sql(sql=sql, action="insert")
+        return self.execute_sql(sql=sql, action="insert", is_need_close=is_need_close)
